@@ -23,6 +23,7 @@ struct SessionInfo {
   std::string osVersion;
   std::string appVersion;
   std::string crossEnvSessionId;
+  std::string systemFingerprint;
 #ifdef __APPLE__
   std::string systemArchitecture;
 #endif
@@ -58,4 +59,9 @@ std::optional<uint64_t> getCiInstanceId();
  */
 std::string getCrossEnvSessionId();
 
+/*
+ * Returns the system fingerprint (the top level digest of the system metadata)
+ */
+std::string getSystemFingerprint();
+
 } // namespace facebook::eden
